from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from curia.api.swagger_client.api.internal_api import InternalApi
from curia.api.swagger_client.api.platform_api import PlatformApi
